pub struct UniversalHash { /* private fields */ }Expand description
UniversalHash v4 hasher
This struct maintains the scratchpads and chain states needed for hashing. It can be reused for multiple hashes to avoid repeated allocations.
Implementations
Sourceimpl UniversalHash
impl UniversalHash